## About
- `Author` : innovationmerge
- `Version`: 1.0
- `Description`: 
    - Contains innovationmerge projects core components. 
    - This package will include core components required to build AI, IoT and other Applications.

## Requirements: 
- `Python > 3.7`

## Install using pip
- `pip install innovationmerge`

## Install using pip
- `poetry add innovationmerge`

## Components

### Edge Computing
1. `Object Detection` - Currently SSD and MobileNet models are supported